.. py:currentmodule:: rubin_scheduler.scheduler

.. _fbs-api:

=================
FBS Scheduler API
=================

Sim Runner
^^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.sim_runner
    :members:
    :show-inheritance:

Example Scheduler
^^^^^^^^^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.example.example_scheduler
    :imported-members:
    :members:
    :show-inheritance:

Model Observatory
^^^^^^^^^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.model_observatory
    :imported-members:
    :members:
    :show-inheritance:

Schedulers
^^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.schedulers
    :imported-members:
    :members:
    :show-inheritance:

Surveys
^^^^^^^

.. automodule:: rubin_scheduler.scheduler.surveys
    :imported-members:
    :members:
    :show-inheritance:

Basis Functions
^^^^^^^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.basis_functions
    :imported-members:
    :members:
    :show-inheritance:

Features
^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.features
    :imported-members:
    :members:
    :show-inheritance:

Detailers
^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.detailers
    :imported-members:
    :members:
    :show-inheritance:

Utils
^^^^^^

.. automodule:: rubin_scheduler.scheduler.utils
    :imported-members:
    :members:
    :show-inheritance:

